@@ -478,9 +478,12 @@ namespace {
 		for(int i = 0; i<2;++i) {
 			fs = buf.find(delim);
 			fields.push_back(buf.substr(0,fs));
-			buf.erase(0,fs + 1);
+			buf.erase(0,fs + delim.length());
 		}
+		if (buf[0] == '"' || buf[0] == '\'')
 		fields.push_back(buf.substr(1, buf.length() - 2));
+		else
+			fields.push_back(buf);
 	}
 
 	void
@@ -489,13 +492,16 @@ namespace {
 		std::vector<std::string> & fields)
 	{
 		std::string buf(line);
-		std::string delim = ", ";
+		std::string delim = ",";
 		std::size_t fs;
 		for(int i = 0; i<3;++i) {
 			fs = buf.rfind(delim);
-			fields.push_back(buf.substr(fs+2, buf.length()));
+			fields.push_back(buf.substr(fs+delim.length(), buf.length()));
 			buf.erase(fs,buf.length());
 		}
+		if (buf[0] == '"' || buf[0] == '\'')
+			fields.push_back(buf.substr(1, buf.length() - 2));
+		else
 		fields.push_back(buf.substr(0, buf.length()));
 	}
 
@@ -602,7 +608,7 @@ namespace {
 						      "Cannot parse maximum address: %s",
 						      csv_fields[V6_CSV_FIELD_MAX_TEXT].c_str());
 				}
-				trie.set_range(minaddr.inetbytes, maxaddr.inetbytes,
+				trie.set_range(minaddr.inet6.s6_addr, maxaddr.inet6.s6_addr,
 					       128, leaf);
 				break;
 
@@ -702,13 +708,13 @@ namespace {
 
 		switch (address_family) {
 		case AF_INET: {
-			const char structure_info[4] = { 0xFF, 0xFF, 0xFF, 9 };
-			dat_stream.write(structure_info, 4);
+			const unsigned char structure_info[4] = { 0xFF, 0xFF, 0xFF, 9 };
+			dat_stream.write((const char *)structure_info, 4);
 			break;
 		}
 		case AF_INET6: {
-			const char structure_info[4] = { 0xFF, 0xFF, 0xFF, 21 };
-			dat_stream.write(structure_info, 4);
+			const unsigned char structure_info[4] = { 0xFF, 0xFF, 0xFF, 21 };
+			dat_stream.write((const char *)structure_info, 4);
 			break;
 		}
 		default:
